package oitc

import (
	"context"
	"testing"
)

func TestConnect(t *testing.T) {
	ctx := context.Background()

	dbh, err := NewDatabase(ctx, "/opt/openitc/etc/mysql/mysql.cnf")
	if err != nil {
		t.Fatal(err)
	}
	defer dbh.Close()

	hosts, err := dbh.FetchHosts()

	if err != nil {
		t.Error(err)
	}

	if len(hosts) == 0 {
		t.Error("List of hosts from MySQL is empty")
	}

	services, err := dbh.FetchServices()

	if err != nil {
		t.Error(err)
	}

	if len(services) == 0 {
		t.Error("List of services from MySQL is empty")
	}

}

func TestFetchWithAndWithoutIdentifier(t *testing.T) {
	ctx := context.Background()

	dbh, err := NewDatabase(ctx, "/opt/openitc/etc/mysql/mysql.cnf")
	if err != nil {
		t.Fatal(err)
	}
	defer dbh.Close()

	hosts, err := dbh.FetchHosts()

	if err != nil {
		t.Error(err)
	}

	if len(hosts) == 0 {
		t.Error("List of hosts from MySQL is empty")
	}

	if hosts[0].Identifier != "" {
		t.Error("Identifier should be empty")
	}

	importedHosts, err := dbh.FetchHostsWithIdentifier()

	if err != nil {
		t.Error(err)
	}

	if len(importedHosts) == 0 {
		t.Error("List of imported hosts from MySQL is empty")
	}

	if importedHosts[0].Identifier == "" {
		t.Error("Identifier should NOT be empty")
	}

	services, err := dbh.FetchServices()

	if err != nil {
		t.Error(err)
	}

	if len(services) == 0 {
		t.Error("List of services from MySQL is empty")
	}

	if services[0].Identifier != "" {
		t.Error("Identifier should be empty")
	}

	importedServices, err := dbh.FetchServicesWithIdentifier()

	if err != nil {
		t.Error(err)
	}

	if len(importedServices) == 0 {
		t.Error("List of imported services from MySQL is empty")
	}

	if importedServices[0].Identifier == "" {
		t.Error("Identifier should NOT be empty")
	}

}
