package prtg

import jsoniter "github.com/json-iterator/go"

type VersionAndObjectCount struct {
	PrtgVersion string `json:"prtg-version,omitempty"` // The PRTG Version e.g.: "23.4.88.1429"
	TreeSize    int64  `json:"treesize,omitempty"`     // Total amount of sensors known to PRTG
}

type Device struct {
	ObjectId int64  `json:"objid,omitempty"`       // Id of the device to query details
	Name     string `json:"name,omitempty"`        // Name of the device
	Active   bool   `json:"active,omitempty"`      // False if paused
	StatusId int64  `json:"status_raw,omitempty"`  // Current state as integer
	Message  string `json:"message_raw,omitempty"` // Check output without HTML
}

type DevicesApiResult struct {
	PrtgVersion string    `json:"prtg-version,omitempty"` // The PRTG Version e.g.: "23.4.88.1429"
	TreeSize    int64     `json:"treesize,omitempty"`     // Total amount of sensors known to PRTG
	Devices     []*Device `json:"devices,omitempty"`      // Device objects as array
}

type Sensor struct {
	ObjectId      int64   `json:"objid,omitempty"`         // Id of the sensor to query details
	Name          string  `json:"name,omitempty"`          // Name of the sensor
	Active        bool    `json:"active,omitempty"`        // False if paused
	StatusId      int64   `json:"status_raw,omitempty"`    // Current state as integer
	Message       string  `json:"message_raw,omitempty"`   // Check output without HTML
	Lastcheck     float64 `json:"lastcheck_raw,omitempty"` // This is a Excel "timestamp" 🤢
	LastcheckUnix int64   `json:",omitempty"`              // Same as Lastcheck but as Unixtimestamp
	Checkinterval int64   `json:"interval_raw,omitempty"`  // Checkinterval in seconds
	DeviceId      int64   `json:"parentid_raw,omitempty"`  // ObjectId of the Device
}

type SensorsApiResult struct {
	PrtgVersion string    `json:"prtg-version,omitempty"` // The PRTG Version e.g.: "23.4.88.1429"
	TreeSize    int64     `json:"treesize,omitempty"`     // Total amount of sensors known to PRTG
	Sensors     []*Sensor `json:"sensors,omitempty"`      // Sensor objects as array
}

type ChannelData struct {
	Status       int64           `json:"status,omitempty"`       // Status of the channel (same to sensor???)
	ObjectId     int64           `json:"id,omitempty"`           // Id of the channel
	Name         string          `json:"name,omitempty"`         // Name of the channel / metric
	IsPercent    bool            `json:"ispercent,omitempty"`    // If the value is in percent or not
	Lastvalue    jsoniter.Any    `json:"lastvalue,omitempty"`    // Last value as string like "0,03 Mbit/s"
	LastvalueRaw jsoniter.Number `json:"lastvalueraw,omitempty"` // LAst value as raw number (207958) however wo get from this to "0,03 Mbit/s"
}

type ChannelInfo struct {
	Data []*ChannelData `json:"data,omitempty"`
}

type Channel struct {
	ObjectId     int64           `json:"objid,omitempty"`         // Id of the channel
	Name         string          `json:"name,omitempty"`          // Name of the channel
	MinimumRaw   jsoniter.Number `json:"minimum_raw,omitempty"`   // Minimum value of the metric
	MaximumRaw   jsoniter.Number `json:"maximum_raw,omitempty"`   // MAximum value of the metric
	ConditionRaw jsoniter.Number `json:"condition_raw,omitempty"` // ?
	LastvalueRaw jsoniter.Number `json:"lastvalue_raw,omitempty"` // Current / latest value of the metric
	InfoRaw      string          `json:"info_raw,omitempty"`      // Info (same as name in my tests)
	Info         *ChannelInfo    `json:"info,omitempty"`          // More information about the current metric
}

type ChannelsApiResult struct {
	PrtgVersion string     `json:"prtg-version,omitempty"` // The PRTG Version e.g.: "23.4.88.1429"
	TreeSize    int64      `json:"treesize,omitempty"`     // Total amount of sensors known to PRTG
	Channels    []*Channel `json:"channels,omitempty"`     // Channel objects as array
}
